==> window_interface-0.3.1.tar.gz: lib/window_interface.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'window_placement.dart';

/// Only supports windows platform.
class WindowInterface {
  static const _eventChannel = EventChannel("window_interface_event");
  static const _methodChannel = MethodChannel('window_interface_method');

  // platform event subscription
  static const int _eventPlacement = 10;
  static late final StreamSubscription _eventSubscription;

  /// subscript to tunnel events
  static void startListen({void Function(WindowPlacement)? onPlacement}) {
    _eventSubscription = _eventChannel.receiveBroadcastStream().listen((data) {
      if (data is! Map || !data.containsKey("event")) {
        return;
      }

      // server id
      if (data["event"] == _eventPlacement) {
        try {
          final placement = WindowPlacement(
            x: data["x"],
            y: data["y"],
            width: data["width"],
            height: data["height"],
          );
          onPlacement?.call(placement);
        } catch (exception) {
          // ignored
        }
      }
    });
    _eventSubscription.resume();
  }

  /// cancel the tunnel events subscription
  static void stopListen() {
    _eventSubscription.cancel();
  }

  static Future<WindowPlacement?> getWindowPlacement() async {
    final map = await _methodChannel.invokeMapMethod<String, int>("getWindowPlacement");
    if (map != null) {
      return WindowPlacement(
        x: map["x"]!,
        y: map["y"]!,
        width: map["width"]!,
        height: map["height"]!,
      );
    }
    return null;
  }

  static Future<bool> setWindowPlacement(WindowPlacement placement) async {
    try {
      await _methodChannel.invokeMethod("setWindowPlacement", {
        "x": placement.x,
        "y": placement.y,
        "width": placement.width,
        "height": placement.height,
      });
      return true;
    } catch (exception) {
      // such as invalid arguments
      return false;
    }
  }

  static Future<bool> getFullScreen() async {
    bool result = await _methodChannel.invokeMethod("getFullScreen");
    return result;
  }

  static Future<void> setFullScreen(bool isFullScreen) async {
    await _methodChannel.invokeMethod("setFullScreen", {'isFullScreen': isFullScreen});
  }

  static Future<void> toggleFullScreen() async {
    await _methodChannel.invokeMethod('toggleFullScreen');
  }

  static Future<Size?> getWindowMinSize() async {
    final map = await _methodChannel.invokeMapMethod<String, int>('getWindowMinSize');
    if (map != null) {
      int width = map["width"]!;
      int height = map["height"]!;
      return Size(width.toDouble(), height.toDouble());
    }
    return null;
  }

  static Future<bool> setWindowMinSize(int width, int height) async {
    try {
      await _methodChannel.invokeMethod('setWindowMinSize', {
        'width': width,
        'height': height,
      });
      return true;
    } catch (exception) {
      return false;
    }
  }

  static Future<void> resetWindowMinSize() async {
    await _methodChannel.invokeMethod('resetWindowMinSize');
  }

  static Future<Size?> getWindowMaxSize() async {
    final map = await _methodChannel.invokeMapMethod<String, int>('getWindowMaxSize');
    if (map != null) {
      int width = map["width"]!;
      int height = map["height"]!;
      return Size(width.toDouble(), height.toDouble());
    }
    return null;
  }

  static Future<bool> setWindowMaxSize(int width, int height) async {
    try {
      await _methodChannel.invokeMethod('setWindowMaxSize', {
        'width': width,
        'height': height,
      });
      return true;
    } catch (exception) {
      return false;
    }
  }

  static Future<void> resetWindowMaxSize() async {
    await _methodChannel.invokeMethod('resetWindowMaxSize');
  }

  static Future<void> setStayOnTop(bool isStayOnTop) async {
    await _methodChannel.invokeMethod('setStayOnTop', {'isStayOnTop': isStayOnTop});
  }
}

==> window_interface-0.4.1.tar.gz: lib/window_interface.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'window_placement.dart';

/// Only supports windows platform.
class WindowInterface {
  static const _eventChannel = EventChannel("window_interface_event");
  static const _methodChannel = MethodChannel('window_interface_method');

  // platform event subscription
  static const int _eventPlacement = 10;
  static StreamSubscription? _eventSubscription;

  /// subscript to tunnel events
  static void startListen({void Function(WindowPlacement)? onPlacement}) {
    _eventSubscription = _eventChannel.receiveBroadcastStream().listen((data) {
      if (data is! Map || !data.containsKey("event")) {
        return;
      }

      // server id
      if (data["event"] == _eventPlacement) {
        try {
          final placement = WindowPlacement(
            x: data["x"],
            y: data["y"],
            width: data["width"],
            height: data["height"],
          );
          onPlacement?.call(placement);
        } catch (exception) {
          // ignored
        }
      }
    });

    _eventSubscription!.resume();
  }

  /// cancel the tunnel events subscription
  static void stopListen() {
    if (_eventSubscription != null) {
      _eventSubscription!.cancel();
      _eventSubscription = null;
    }
  }

  static Future<WindowPlacement?> getWindowPlacement() async {
    final map = await _methodChannel.invokeMapMethod<String, int>("getWindowPlacement");
    if (map != null) {
      return WindowPlacement(
        x: map["x"]!,
        y: map["y"]!,
        width: map["width"]!,
        height: map["height"]!,
      );
    }
    return null;
  }

  static Future<bool> setWindowPlacement(WindowPlacement placement) async {
    try {
      await _methodChannel.invokeMethod("setWindowPlacement", {
        "x": placement.x,
        "y": placement.y,
        "width": placement.width,
        "height": placement.height,
      });
      return true;
    } catch (exception) {
      // such as invalid arguments
      return false;
    }
  }

  static Future<bool> getFullScreen() async {
    bool result = await _methodChannel.invokeMethod("getFullScreen");
    return result;
  }

  static Future<void> setFullScreen(bool isFullScreen) async {
    await _methodChannel.invokeMethod("setFullScreen", {'isFullScreen': isFullScreen});
  }

  static Future<void> toggleFullScreen() async {
    await _methodChannel.invokeMethod('toggleFullScreen');
  }

  static Future<Size?> getWindowMinSize() async {
    final map = await _methodChannel.invokeMapMethod<String, int>('getWindowMinSize');
    if (map != null) {
      int width = map["width"]!;
      int height = map["height"]!;
      return Size(width.toDouble(), height.toDouble());
    }
    return null;
  }

  static Future<bool> setWindowMinSize(int width, int height) async {
    try {
      await _methodChannel.invokeMethod('setWindowMinSize', {
        'width': width,
        'height': height,
      });
      return true;
    } catch (exception) {
      return false;
    }
  }

  static Future<void> resetWindowMinSize() async {
    await _methodChannel.invokeMethod('resetWindowMinSize');
  }

  static Future<Size?> getWindowMaxSize() async {
    final map = await _methodChannel.invokeMapMethod<String, int>('getWindowMaxSize');
    if (map != null) {
      int width = map["width"]!;
      int height = map["height"]!;
      return Size(width.toDouble(), height.toDouble());
    }
    return null;
  }

  static Future<bool> setWindowMaxSize(int width, int height) async {
    try {
      await _methodChannel.invokeMethod('setWindowMaxSize', {
        'width': width,
        'height': height,
      });
      return true;
    } catch (exception) {
      return false;
    }
  }

  static Future<void> resetWindowMaxSize() async {
    await _methodChannel.invokeMethod('resetWindowMaxSize');
  }

  static Future<void> setStayOnTop(bool isStayOnTop) async {
    await _methodChannel.invokeMethod('setStayOnTop', {'isStayOnTop': isStayOnTop});
  }
}
